@@ -23,8 +23,10 @@ typedef unsigned char jmp_buf[24];  // R2-R19, R28-R29, PC, SP: 8K-128K devices
 #endif
 #elif defined(__CROSSWORKS_MSP430)
 typedef unsigned jmp_buf[10];       // R4-R11, PC, SP
+#elif defined(__CROSSWORKS_MAXQ)
+typedef unsigned jmp_buf[14];       // A[0]-A[3], A[8]-A[15], SP, PC
 #elif defined(__GNUC__)
-typedef unsigned jmp_buf[13];
+typedef unsigned jmp_buf[11];       // R4-R14
 #endif
 
 int setjmp(jmp_buf env);
