@@ -1,4 +1,4 @@
-// Copyright (c) 2001-2004 Rowley Associates Limited.
+// Copyright (c) 2001-2005 Rowley Associates Limited.
 //
 // This file may be distributed under the terms of the License Agreement
 // provided with this software.
@@ -8,7 +8,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 //
-//           Logic Product Development SDKLH75401-10 LED Example
+//           Logic Product Development SDKLH79520-10 LED Example
 //
 // Description
 // -----------
@@ -17,11 +17,11 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#include <targets/LH754xx.h>
+#include <targets/LH79520.h>
 
 extern void delay(volatile unsigned int d);
 
-#define GPIO_REG *((volatile unsigned char *)0x4C580000)
+#define EXTENDED_GPIO_REG *((volatile unsigned char *)0x55600000)
 
 static void
 cycle(int n)
@@ -29,17 +29,17 @@ cycle(int n)
   int m = 0;
   for (; n; m++, n--)
     {
-      GPIO_REG &= ~1;
+      EXTENDED_GPIO_REG &= ~3;
       delay(m);
-      GPIO_REG |= 1;
+      EXTENDED_GPIO_REG |= 3;
       delay(n);
     }
 
   for (; m; m--, n++)
     {
-      GPIO_REG &= ~1;
+      EXTENDED_GPIO_REG &= ~3;
       delay(m);
-      GPIO_REG |= 1;
+      EXTENDED_GPIO_REG |= 3;
       delay(n);
     }
 }
