@@ -1,8 +1,6 @@
 function Reset()
 {
-  TargetInterface.setICEBreakerBreakpoint(0, 0x00000000, 0xFFFFFFFF, 0x00000000, 0xFFFFFFFF, 0x100, 0xF7);
-  TargetInterface.waitForDebugState(1000);
-  TargetInterface.trst();
+  TargetInterface.stopAndReset(1);
 }
 
 function SRAMReset()
