@@ -1,5 +1,5 @@
 /******************************************************************************
-  Target Script for LPD SDKLH79524_10.
+  Target Script for LPD SDKLH79520_10.
 
   Copyright (c) 2005 Rowley Associates Limited.
 
@@ -10,7 +10,6 @@
   WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  ******************************************************************************/
 
-
 function Reset()
 {
   TargetInterface.trst();
@@ -26,12 +25,12 @@ function Reset()
 function RAMReset()
 {
   Reset();
-  TargetInterface.pokeWord(0xFFFE2008, 2); /* RCPC_REMAP: Locate internal static memory at 0x00000000 */
+  TargetInterface.pokeWord(0xFFFE2008, 2); /* RCPCRemapCtrl: Locate internal static memory at 0x00000000 */
 }
 
 function FLASHReset()
 {
   Reset();
-  TargetInterface.pokeWord(0xFFFE2008, 0); /* RCPC_REMAP: Locate external static memory at 0x00000000 */
+  TargetInterface.pokeWord(0xFFFE2008, 0); /* RCPCRemapCtrl: Locate external static memory at 0x00000000 */
 }
 
